#ifndef GUI_H
#define GUI_H

#include "SDL.h"
#include "SDL_ttf.h" 
#include "loadimage.h"
#include "levelcontainer.h"
#include "player.h"
#include "masterclass.h"
#include "enemy.h"
#include "missile.h"
#include "missilecontainer.h"
#include <time.h>
#include <math.h>

#define WIDTH 640
#define HEIGHT 480
#define INFOBARHEIGHT 60
#define PLAYER "Resources/player.png"
#define TITLE "potcat."
#define FONT "Resources/FreeSans.ttf"
#define FONTSIZE 32
#define MAXMISSILES 25
#define MAXENEMIES 5

class Gui
{
	public:
		int xpos, ypos, xvel, yvel, plheight, plwidth, bgpos;
		void loadImages();
		void loadFonts();
		void loadEnemies();
		void loadMissiles();
		void update();
		void levelChange();
		void addMissile(Missile *m);
		static Gui* getInstance();
	private:
		SDL_Surface *screen, *plimage, *bgimage;
		SDL_Rect dest;
		SDL_Event event;
		TTF_Font *font;

		Missile missiles[MAXMISSILES];
		Enemy enemies[MAXENEMIES];
		MapObject *activeObject;

		bool left_pressed, right_pressed, up_pressed, down_pressed, moved;

		int bgcolor, waitForEnemies;

		void gameOver();
		void keyUp(SDL_KeyboardEvent*);
		void keyDown(SDL_KeyboardEvent*);
		void redraw();
		void move();
		void moveMissiles();
		void moveEnemies();
		void redrawPanel();
		void redrawBackground();
		void redrawPlayer();
		void redrawEntrances();
		void redrawMissiles();
		void redrawEnemies();
		void reloadBackground();
		void resetPosition();
		void checkActiveObject();
		void checkEnemyHit();
		void checkPlayerHit();
		void produceRandomEncounters();
		void addEnemy();
		void delEnemy(int i);
		void delMissile(int i);
		static Gui *instance;
		Gui();
};
#endif